@@ -2,13 +2,15 @@
 # Copyright 2018 Open Source Geospatial Foundation and others    #
 # licensed under MIT, Please consult LICENSE.txt for details     #
 ##################################################################
+import json
 import tempfile
 from pathlib import Path
 
-import lxml.etree
+import lxml
+from pywps import xml_util as etree
 import requests
 from werkzeug.test import Client
-from werkzeug.wrappers import BaseResponse
+from werkzeug.wrappers import Response
 from pywps import __version__
 from pywps import Process
 from pywps.inout import LiteralInput, LiteralOutput, ComplexInput, ComplexOutput, BoundingBoxInput, BoundingBoxOutput
@@ -93,17 +95,27 @@ class WpsClient(Client):
 
     def post_xml(self, *args, **kwargs):
         doc = kwargs.pop('doc')
-        data = lxml.etree.tostring(doc, pretty_print=True)
+        data = etree.tostring(doc, pretty_print=True)
         kwargs['data'] = data
         return self.post(*args, **kwargs)
 
+    def post_json(self, *args, **kwargs):
+        doc = kwargs.pop('doc')
+        # data = json.dumps(doc, indent=2)
+        # kwargs['data'] = data
+        kwargs['json'] = doc
+        # kwargs['content_type'] = 'application/json'  # input is json, redundant as it's deducted from the json kwarg
+        # kwargs['mimetype'] = 'application/json'  # output is json
+        kwargs['environ_base'] = {'HTTP_ACCEPT': 'application/json'}  # output is json
+        return self.post(*args, **kwargs)
 
-class WpsTestResponse(BaseResponse):
+
+class WpsTestResponse(Response):
 
     def __init__(self, *args):
         super(WpsTestResponse, self).__init__(*args)
         if re.match(r'text/xml(;\s*charset=.*)?', self.headers.get('Content-Type')):
-            self.xml = lxml.etree.fromstring(self.get_data())
+            self.xml = etree.fromstring(self.get_data())
 
     def xpath(self, path):
         version = self.xml.attrib["version"]
@@ -143,9 +155,30 @@ def assert_process_started(resp):
     assert success.split[0] == "processstarted"
 
 
+def assert_response_success_json(resp, expected_data):
+    assert resp.status_code == 200
+
+    content_type = resp.headers['Content-Type']
+    expected_contect_type = 'application/json'
+    re_content_type = rf'{expected_contect_type}(;\s*charset=.*)?'
+    assert re.match(re_content_type, content_type)
+
+    data = json.loads(resp.data)
+
+    success = data['status']['status']
+    assert success == 'succeeded'
+
+    if expected_data:
+        outputs = data['outputs']
+        assert outputs == expected_data
+
+
 def assert_response_success(resp):
     assert resp.status_code == 200
-    assert re.match(r'text/xml(;\s*charset=.*)?', resp.headers['Content-Type'])
+    content_type = resp.headers['Content-Type']
+    expected_contect_type = 'text/xml'
+    re_content_type = rf'{expected_contect_type}(;\s*charset=.*)?'
+    assert re.match(re_content_type, content_type)
     success = resp.xpath('/wps:ExecuteResponse/wps:Status/wps:ProcessSucceeded')
     assert len(success) == 1
 
