@@ -4,7 +4,8 @@
 ##################################################################
 
 import unittest
-import lxml.etree
+import pytest
+from pywps import xml_util as etree
 import json
 import tempfile
 import os.path
@@ -12,19 +13,14 @@ from pywps import Service, Process, LiteralOutput, LiteralInput,\
     BoundingBoxOutput, BoundingBoxInput, Format, ComplexInput, ComplexOutput, FORMATS
 from pywps.validator.base import emptyvalidator
 from pywps.validator.complexvalidator import validategml
-from pywps.validator.mode import MODE
 from pywps.exceptions import InvalidParameterValue
-from pywps import get_inputs_from_xml, get_output_from_xml
+from pywps import get_inputs_from_xml
 from pywps import E, get_ElementMakerForVersion
 from pywps.app.basic import get_xpath_ns
-from pywps._compat import text_type
-from pywps.tests import client_for, assert_response_success
-from pywps.configuration import CONFIG
+from pywps.tests import client_for, assert_response_success, assert_response_success_json
+from pywps import configuration
 
-from pywps._compat import PY2
-from pywps._compat import StringIO
-if PY2:
-    from owslib.ows import BoundingBox
+from io import StringIO
 
 try:
     import netCDF4
@@ -56,7 +52,7 @@ def create_ultimate_question():
 def create_greeter():
     def greeter(request, response):
         name = request.inputs['name'][0].data
-        assert type(name) is text_type
+        assert isinstance(name, str)
         response.outputs['message'].data = "Hello {}!".format(name)
         return response
 
@@ -116,12 +112,17 @@ def create_bbox_process():
                    outputs=[BoundingBoxOutput('outbbox', 'Output message', ["EPSG:4326"])])
 
 
-def create_complex_proces():
+def create_complex_proces(mime_type: str = 'gml'):
     def complex_proces(request, response):
-        response.outputs['complex'].data = request.inputs['complex'][0].data
+        response.outputs['complex'].data = request.inputs['complex'][0].data_as_json()
         return response
 
-    frmt = Format(mime_type='application/gml', extension=".gml")  # this is unknown mimetype
+    if mime_type == 'gml':
+        frmt = Format(mime_type='application/gml', extension=".gml")  # this is unknown mimetype
+    elif mime_type == 'geojson':
+        frmt = FORMATS.GEOJSON
+    else:
+        raise Exception(f'Unknown mime type {mime_type}')
 
     return Process(handler=complex_proces,
                    identifier='my_complex_process',
@@ -130,6 +131,7 @@ def create_complex_proces():
                        ComplexInput(
                            'complex',
                            'Complex input',
+                           min_occurs=0,
                            default="DEFAULT COMPLEX DATA",
                            supported_formats=[frmt])
                    ],
@@ -225,7 +227,7 @@ def get_output(doc):
                 output[identifier_el.text] = data_el[0].text
             else:  # XML children
                 ch = list(data_el[0])[0]
-                output[identifier_el.text] = lxml.etree.tostring(ch)
+                output[identifier_el.text] = etree.tostring(ch)
 
     return output
 
@@ -233,9 +235,8 @@ def get_output(doc):
 class ExecuteTest(unittest.TestCase):
     """Test for Exeucte request KVP request"""
 
+    @pytest.mark.xfail(reason="test.opendap.org is offline")
     def test_dods(self):
-        if PY2:
-            self.skipTest('fails on python 2.7')
         if not WITH_NC4:
             self.skipTest('netCDF4 not installed')
         my_process = create_complex_nc_process()
@@ -282,7 +283,7 @@ class ExecuteTest(unittest.TestCase):
         request = FakeRequest()
 
         resp = service.execute('my_opendap_process', request, 'fakeuuid')
-        self.assertEqual(resp.outputs['conventions'].data, u'CF-1.0')
+        self.assertEqual(resp.outputs['conventions'].data, 'CF-1.0')
         self.assertEqual(resp.outputs['outdods'].url, href)
         self.assertTrue(resp.outputs['outdods'].as_reference)
         self.assertFalse(resp.outputs['ncraw'].as_reference)
@@ -295,7 +296,7 @@ class ExecuteTest(unittest.TestCase):
         """
         my_process = create_complex_proces()
         service = Service(processes=[my_process])
-        self.assertEqual(len(service.processes.keys()), 1)
+        self.assertEqual(len(service.processes), 1)
         self.assertTrue(service.processes['my_complex_process'])
 
         class FakeRequest():
@@ -352,7 +353,7 @@ class ExecuteTest(unittest.TestCase):
         """
         my_process = create_complex_proces()
         service = Service(processes=[my_process])
-        self.assertEqual(len(service.processes.keys()), 1)
+        self.assertEqual(len(service.processes), 1)
         self.assertTrue(service.processes['my_complex_process'])
 
         class FakeRequest():
@@ -376,7 +377,7 @@ class ExecuteTest(unittest.TestCase):
         """
         my_process = create_mimetype_process()
         service = Service(processes=[my_process])
-        self.assertEqual(len(service.processes.keys()), 1)
+        self.assertEqual(len(service.processes), 1)
         self.assertTrue(service.processes['get_mimetype_process'])
 
         class FakeRequest():
@@ -425,31 +426,52 @@ class ExecuteTest(unittest.TestCase):
         assert get_output(resp.xml) == {'outvalue': '42'}
 
     def test_post_with_no_inputs(self):
+        request = {
+            'identifier': 'ultimate_question',
+            'version': '1.0.0'
+        }
+        result = {'outvalue': '42'}
+
         client = client_for(Service(processes=[create_ultimate_question()]))
         request_doc = WPS.Execute(
-            OWS.Identifier('ultimate_question'),
-            version='1.0.0'
+            OWS.Identifier(request['identifier']),
+            version=request['version']
         )
 
         resp = client.post_xml(doc=request_doc)
         assert_response_success(resp)
-        assert get_output(resp.xml) == {'outvalue': '42'}
+        assert get_output(resp.xml) == result
+
+        resp = client.post_json(doc=request)
+        assert_response_success_json(resp, result)
 
     def test_post_with_string_input(self):
+        request = {
+            'identifier': 'greeter',
+            'version': '1.0.0',
+            'inputs': {
+                'name': 'foo'
+            },
+        }
+        result = {'message': "Hello foo!"}
+
         client = client_for(Service(processes=[create_greeter()]))
         request_doc = WPS.Execute(
-            OWS.Identifier('greeter'),
+            OWS.Identifier(request['identifier']),
             WPS.DataInputs(
                 WPS.Input(
                     OWS.Identifier('name'),
-                    WPS.Data(WPS.LiteralData('foo'))
+                    WPS.Data(WPS.LiteralData(request['inputs']['name']))
                 )
             ),
-            version='1.0.0'
+            version=request['version']
         )
         resp = client.post_xml(doc=request_doc)
         assert_response_success(resp)
-        assert get_output(resp.xml) == {'message': "Hello foo!"}
+        assert get_output(resp.xml) == result
+
+        resp = client.post_json(doc=request)
+        assert_response_success_json(resp, result)
 
     def test_bbox(self):
         client = client_for(Service(processes=[create_bbox_process()]))
@@ -483,6 +505,47 @@ class ExecuteTest(unittest.TestCase):
         upper_corner = upper_corner.strip().replace('  ', ' ')
         self.assertEqual('16.0 51.0', upper_corner)
 
+    def test_bbox_rest(self):
+        client = client_for(Service(processes=[create_bbox_process()]))
+        bbox = [15.0, 50.0, 16.0, 51.0]
+        request = dict(
+            identifier='my_bbox_process',
+            version='1.0.0',
+            inputs={
+                'mybbox': {
+                    "type": "bbox",
+                    'bbox': bbox,
+                }
+            },
+        )
+        result = {'outbbox': bbox}
+
+        resp = client.post_json(doc=request)
+        assert_response_success_json(resp, result)
+
+    def test_geojson_input_rest(self):
+        geojson = os.path.join(DATA_DIR, 'json', 'point.geojson')
+        with open(geojson) as f:
+            p = json.load(f)
+
+        my_process = create_complex_proces('geojson')
+        client = client_for(Service(processes=[my_process]))
+
+        request = dict(
+            identifier='my_complex_process',
+            version='1.0.0',
+            inputs={
+                'complex': {
+                    "type": "complex",
+                    'data': p
+                }
+            },
+        )
+        result = {'complex': p}
+
+        resp = client.post_json(doc=request)
+        assert_response_success_json(resp, result)
+
     def test_output_response_dataType(self):
         client = client_for(Service(processes=[create_greeter()]))
         request_doc = WPS.Execute(
@@ -500,13 +563,47 @@ class ExecuteTest(unittest.TestCase):
         assert el.attrib['dataType'] == 'string'
 
 
+class AllowedInputReferenceExecuteTest(unittest.TestCase):
+
+    def setUp(self):
+        self.allowedinputpaths = configuration.get_config_value('server', 'allowedinputpaths')
+        configuration.CONFIG.set('server', 'allowedinputpaths', DATA_DIR)
+
+    def tearDown(self):
+        configuration.CONFIG.set('server', 'allowedinputpaths', self.allowedinputpaths)
+
+    def test_geojson_input_reference_rest(self):
+        geojson = os.path.join(DATA_DIR, 'json', 'point.geojson')
+        with open(geojson) as f:
+            p = json.load(f)
+
+        my_process = create_complex_proces('geojson')
+        client = client_for(Service(processes=[my_process]))
+
+        request = dict(
+            identifier='my_complex_process',
+            version='1.0.0',
+            inputs={
+                'complex': {
+                    "type": "reference",
+                    "href": f"file:{geojson}"
+                }
+            },
+        )
+        result = {'complex': p}
+
+        resp = client.post_json(doc=request)
+        assert_response_success_json(resp, result)
+
+
 class ExecuteTranslationsTest(unittest.TestCase):
 
     def setUp(self):
-        CONFIG.set('server', 'language', 'en-US,fr-CA')
+        configuration.get_config_value('server', 'language')
+        configuration.CONFIG.set('server', 'language', 'en-US,fr-CA')
 
     def tearDown(self):
-        CONFIG.set('server', 'language', 'en-US')
+        configuration.CONFIG.set('server', 'language', 'en-US')
 
     def test_translations(self):
         client = client_for(Service(processes=[create_translated_greeter()]))
@@ -602,7 +699,7 @@ class ExecuteXmlParserTest(unittest.TestCase):
                         WPS.ComplexData(the_data, mimeType='text/foobar')))))
         rv = get_inputs_from_xml(request_doc)
         self.assertEqual(rv['name'][0]['mimeType'], 'text/foobar')
-        rv_doc = lxml.etree.parse(StringIO(rv['name'][0]['data'])).getroot()
+        rv_doc = etree.parse(StringIO(rv['name'][0]['data'])).getroot()
         self.assertEqual(rv_doc.tag, 'TheData')
         self.assertEqual(rv_doc.text, 'hello world')
 
@@ -639,8 +736,6 @@ class ExecuteXmlParserTest(unittest.TestCase):
         self.assertEqual(json_data['plot']['Version'], '0.1')
 
     def test_bbox_input(self):
-        if not PY2:
-            self.skipTest('OWSlib not python 3 compatible')
         request_doc = WPS.Execute(
             OWS.Identifier('request'),
             WPS.DataInputs(
@@ -652,11 +747,12 @@ class ExecuteXmlParserTest(unittest.TestCase):
                             OWS.UpperCorner('60 70'))))))
         rv = get_inputs_from_xml(request_doc)
         bbox = rv['bbox'][0]
-        assert isinstance(bbox, BoundingBox)
-        assert bbox.minx == '40'
-        assert bbox.miny == '50'
-        assert bbox.maxx == '60'
-        assert bbox.maxy == '70'
+        # assert isinstance(bbox, BoundingBox)
+        assert bbox['data'] == ['40', '50', '60', '70']
+        # assert bbox.minx == '40'
+        # assert bbox.miny == '50'
+        # assert bbox.maxx == '60'
+        # assert bbox.maxy == '70'
 
     def test_reference_post_input(self):
         request_doc = WPS.Execute(
